"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const time_1 = require("./time");
class Flight {
    getScheduleDate(dateInput) {
        const dateSplit = dateInput.split('-').map(part => parseInt(part, 10));
        return new Date(dateSplit[0], dateSplit[1] - 1, dateSplit[2]);
    }
    getTime(timeInput) {
        if (!timeInput) {
            return;
        }
        const timeSplit = timeInput.split(':').map(part => parseInt(part, 10));
        return new time_1.default(timeSplit[0], timeSplit[1], timeSplit[2]);
    }
    getDate(dateInput) {
        if (!dateInput) {
            return;
        }
        return new Date(dateInput);
    }
    getArray(arrayInput, key) {
        if (!arrayInput) {
            return [];
        }
        return arrayInput[key];
    }
    getIntArray(arrayInput, key) {
        if (!arrayInput) {
            return [];
        }
        return arrayInput[key].map(value => parseInt(value, 10));
    }
    setCheckinAllocations(checkinAllocations) {
        if (!checkinAllocations) {
            return;
        }
        this.checkinAllocationRemarks = checkinAllocations.remarks;
        this.checkinAllocations = checkinAllocations.checkinAllocations.map(allocation => ({
            startTime: new Date(allocation.startTime),
            endTime: new Date(allocation.endTime),
            rows: allocation.rows.rows.map(row => ({
                position: parseInt(row.position, 10),
                desks: row.desks.desks,
            })),
        }));
    }
    constructor(flightInfo) {
        this.id = flightInfo.id;
        // the "normal" properties
        this.flightName = flightInfo.flightName;
        this.flightNumber = flightInfo.flightNumber;
        this.prefixIATA = flightInfo.prefixIATA;
        this.prefixICAO = flightInfo.prefixICAO;
        this.serviceType = flightInfo.serviceType;
        this.mainFlight = flightInfo.mainFlight;
        this.terminal = flightInfo.terminal;
        this.gate = flightInfo.gate;
        this.expectedTimeOnBelt = flightInfo.expectedTimeOnBelt;
        this.setCheckinAllocations(flightInfo.checkinAllocations);
        this.aircraftType = flightInfo.aircraftType;
        this.aircraftRegistration = flightInfo.aircraftRegistration;
        this.airlineCode = flightInfo.airlineCode;
        // the special properties
        this.scheduleDate = this.getScheduleDate(flightInfo.scheduleDate);
        this.isArrival = flightInfo.flightDirection === 'A';
        // the arrays
        this.codeshares = this.getArray(flightInfo.codeshares, 'codeshares');
        this.publicFlightState = this.getArray(flightInfo.publicFlightState, 'flightStates');
        this.route = this.getArray(flightInfo.route, 'destinations');
        this.baggageClaim = this.getArray(flightInfo.baggageClaim, 'belts');
        this.transferPositions = this.getIntArray(flightInfo.transferPositions, 'transferPositions');
        // the times
        this.scheduleTime = this.getTime(flightInfo.scheduleTime);
        // the dates
        this.estimatedLandingTime = this.getDate(flightInfo.estimatedLandingTime);
        this.actualLandingTime = this.getDate(flightInfo.actualLandingTime);
        this.actualOffBlockTime = this.getDate(flightInfo.actualOffBlockTime);
        this.publicEstimatedOffBlockTime = this.getDate(flightInfo.publicEstimatedOffBlockTime);
        this.expectedTimeGateOpen = this.getDate(flightInfo.expectedTimeGateOpen);
        this.expectedTimeBoarding = this.getDate(flightInfo.expectedTimeBoarding);
        this.expectedTimeGateClosing = this.getDate(flightInfo.expectedTimeGateClosing);
    }
}
exports.Flight = Flight;
